from ftw.colorbox.interfaces import IColorboxSettings
from Products.Five.browser import BrowserView
from zope.component import getUtility
from plone.registry.interfaces import IRegistry


class InitColorBoxView(BrowserView):

    def __call__(self):
        registry = getUtility(IRegistry)
        settings = registry.forInterface(IColorboxSettings)
        return """
            var ftwColorboxInitialize = function() {
                var staticOptions = {
                    'title': function(){
                        var link = $(this);
                        var title = link.attr('title');

                        // Use the value from the attrib "data-caption" if there is one.
                        var caption = link.data('caption');
                        if (caption) {
                            title = caption;
                        }

                        return title;
                    }
                }
                var options = {%s}  // The options stored in the Plone registry.
                $.extend(options, staticOptions)
                $('a.colorboxLink').colorbox(options);
            }
            jQuery(function($) {
                ftwColorboxInitialize();
            });
        """ % ','.join(settings.colorbox_config)



from plone.app.testing import applyProfile
from plone.app.testing import FunctionalTesting
from plone.app.testing import PLONE_FIXTURE
from plone.app.testing import PloneSandboxLayer
from zope.configuration import xmlconfig


class FtwColorboxLayer(PloneSandboxLayer):

    defaultBases = (PLONE_FIXTURE, )

    def setUpZope(self, app, configurationContext):
        xmlconfig.string(
            '<configure xmlns="http://namespaces.zope.org/zope">'
            '  <include package="z3c.autoinclude" file="meta.zcml" />'
            '  <includePlugins package="plone" />'
            '  <includePluginsOverrides package="plone" />'
            '</configure>',
            context=configurationContext)

    def setUpPloneSite(self, portal):
        # Install into Plone site using portal_setup
        applyProfile(portal, 'ftw.colorbox:default')

FTW_COLORBOX_FIXTURE = FtwColorboxLayer()

FTW_COLORBOX_FUNCTIONAL_TESTING = FunctionalTesting(
    bases=(FTW_COLORBOX_FIXTURE, ),
    name='ftw.colorbox:functional')



from ftw.colorbox.testing import FTW_COLORBOX_FUNCTIONAL_TESTING
from plone.app.testing import setRoles
from plone.app.testing import TEST_USER_ID
from unittest2 import TestCase
import transaction


class FunctionalTestCase(TestCase):
    layer = FTW_COLORBOX_FUNCTIONAL_TESTING

    def setUp(self):
        self.portal = self.layer['portal']
        self.request = self.layer['request']

    def grant(self, *roles):
        setRoles(self.portal, TEST_USER_ID, roles)
        transaction.commit()



from Products.CMFCore.utils import getToolByName
from ftw.colorbox.tests import FunctionalTestCase


class TestInstallation(FunctionalTestCase):

    def test_generic_setup_profile_is_installed(self):
        portal_setup = getToolByName(self.layer['portal'], 'portal_setup')
        version = portal_setup.getLastVersionForProfile('ftw.colorbox:default')
        self.assertNotEquals('unknown', version)



from zope.i18n import translate
from ftw.colorbox.interfaces import IColorboxSettings
from Products.Five.browser import BrowserView
from zope.component import getUtility
from plone.registry.interfaces import IRegistry
from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile


class ColorBoxView(BrowserView):
    template = ViewPageTemplateFile('colorbox_view.pt')

    def __call__(self):
        registry = getUtility(IRegistry)
        self.settings = registry.forInterface(IColorboxSettings)
        return self.template()

    def image_title(self, image):
        """ Returns the image title and the link to the original file if
            'show_link' in registry is true.
        """
        title = [image.Title().decode('utf8')]
        if self.settings.show_link:
            title.append('<a href="%s/at_download/image">%s</a>' % (
                image.absolute_url(),
                translate(u'download',
                          domain='ftw.colorbox',
                          context=self.request)))
        return ' '.join(title)

    def image_size_suffix(self):
        """The suffix that is appended to the image url to get the
           configured image size."""
        if self.settings.image_size:
            return '/@@images/image/%s' % self.settings.image_size
        return ''

    def rows(self, batch):
        """Yield successive n-sized chunks.
        """
        row_size = self.settings.row_size
        if row_size < 1:
            yield batch
        else:
            batch = list(batch)
            for i in xrange(0, len(batch), row_size):
                yield batch[i:i+row_size]
